==> owncloud-4.5.7.tgz: owncloud/apps/files/l10n/hr.php <==
<?php $TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "Datoteka je poslana uspješno i bez pogrešaka",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Poslana datoteka izlazi iz okvira upload_max_size direktive postavljene u php.ini konfiguracijskoj datoteci",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Poslana datoteka izlazi iz okvira MAX_FILE_SIZE direktive postavljene u HTML obrascu",
"The uploaded file was only partially uploaded" => "Datoteka je poslana samo djelomično",
"No file was uploaded" => "Ni jedna datoteka nije poslana",
"Missing a temporary folder" => "Nedostaje privremena mapa",
"Failed to write to disk" => "Neuspjelo pisanje na disk",
"Files" => "Datoteke",
"Unshare" => "Prekini djeljenje",
"Delete" => "Briši",
"Rename" => "Promjeni ime",
"already exists" => "već postoji",
"replace" => "zamjeni",
"suggest name" => "predloži ime",
"cancel" => "odustani",
"replaced" => "zamjenjeno",
"undo" => "vrati",
"with" => "sa",
"unshared" => "maknuto djeljenje",
"deleted" => "izbrisano",
"generating ZIP-file, it may take some time." => "generiranje ZIP datoteke, ovo može potrajati.",
"Unable to upload your file as it is a directory or has 0 bytes" => "Nemoguće poslati datoteku jer je prazna ili je direktorij",
"Upload Error" => "Pogreška pri slanju",
"Pending" => "U tijeku",
"1 file uploading" => "1 datoteka se učitava",
"files uploading" => "datoteke se učitavaju",
"Upload cancelled." => "Slanje poništeno.",
"File upload is in progress. Leaving the page now will cancel the upload." => "Učitavanje datoteke. Napuštanjem stranice će prekinuti učitavanje.",
"Invalid name, '/' is not allowed." => "Neispravan naziv, znak '/' nije dozvoljen.",
"files scanned" => "datoteka skenirana",
"error while scanning" => "grečka prilikom skeniranja",
"Name" => "Naziv",
"Size" => "Veličina",
"Modified" => "Zadnja promjena",
"folder" => "mapa",
"folders" => "mape",
"file" => "datoteka",
"files" => "datoteke",
"seconds ago" => "sekundi prije",
"minute ago" => "minutu",
"minutes ago" => "minuta",
"today" => "danas",
"yesterday" => "jučer",
"days ago" => "dana",
"last month" => "prošli mjesec",
"months ago" => "mjeseci",
"last year" => "prošlu godinu",
"years ago" => "godina",
"File handling" => "datoteka za rukovanje",
"Maximum upload size" => "Maksimalna veličina prijenosa",
"max. possible: " => "maksimalna moguća: ",
"Needed for multi-file and folder downloads." => "Potrebno za preuzimanje više datoteke i mape",
"Enable ZIP-download" => "Omogući ZIP-preuzimanje",
"0 is unlimited" => "0 je \"bez limita\"",
"Maximum input size for ZIP files" => "Maksimalna veličina za ZIP datoteke",
"Save" => "Snimi",
"New" => "novo",
"Text file" => "tekstualna datoteka",
"Folder" => "mapa",
"From url" => "od URL-a",
"Upload" => "Pošalji",
"Cancel upload" => "Prekini upload",
"Nothing in here. Upload something!" => "Nema ničega u ovoj mapi. Pošalji nešto!",
"Share" => "podjeli",
"Download" => "Preuzmi",
"Upload too large" => "Prijenos je preobiman",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "Datoteke koje pokušavate prenijeti prelaze maksimalnu veličinu za prijenos datoteka na ovom poslužitelju.",
"Files are being scanned, please wait." => "Datoteke se skeniraju, molimo pričekajte.",
"Current scanning" => "Trenutno skeniranje"
);

==> owncloud-5.0.9.tgz: owncloud/apps/files/l10n/hr.php <==
<?php $TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "Datoteka je poslana uspješno i bez pogrešaka",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Poslana datoteka izlazi iz okvira MAX_FILE_SIZE direktive postavljene u HTML obrascu",
"The uploaded file was only partially uploaded" => "Datoteka je poslana samo djelomično",
"No file was uploaded" => "Ni jedna datoteka nije poslana",
"Missing a temporary folder" => "Nedostaje privremena mapa",
"Failed to write to disk" => "Neuspjelo pisanje na disk",
"Files" => "Datoteke",
"Share" => "Podijeli",
"Delete" => "Briši",
"Rename" => "Promjeni ime",
"Pending" => "U tijeku",
"replace" => "zamjeni",
"suggest name" => "predloži ime",
"cancel" => "odustani",
"undo" => "vrati",
"Unable to upload your file as it is a directory or has 0 bytes" => "Nemoguće poslati datoteku jer je prazna ili je direktorij",
"Upload Error" => "Pogreška pri slanju",
"Close" => "Zatvori",
"1 file uploading" => "1 datoteka se učitava",
"Upload cancelled." => "Slanje poništeno.",
"File upload is in progress. Leaving the page now will cancel the upload." => "Učitavanje datoteke. Napuštanjem stranice će prekinuti učitavanje.",
"Name" => "Naziv",
"Size" => "Veličina",
"Modified" => "Zadnja promjena",
"Upload" => "Pošalji",
"File handling" => "datoteka za rukovanje",
"Maximum upload size" => "Maksimalna veličina prijenosa",
"max. possible: " => "maksimalna moguća: ",
"Needed for multi-file and folder downloads." => "Potrebno za preuzimanje više datoteke i mape",
"Enable ZIP-download" => "Omogući ZIP-preuzimanje",
"0 is unlimited" => "0 je \"bez limita\"",
"Maximum input size for ZIP files" => "Maksimalna veličina za ZIP datoteke",
"Save" => "Snimi",
"New" => "novo",
"Text file" => "tekstualna datoteka",
"Folder" => "mapa",
"Cancel upload" => "Prekini upload",
"Nothing in here. Upload something!" => "Nema ničega u ovoj mapi. Pošalji nešto!",
"Download" => "Preuzmi",
"Unshare" => "Prekini djeljenje",
"Upload too large" => "Prijenos je preobiman",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "Datoteke koje pokušavate prenijeti prelaze maksimalnu veličinu za prijenos datoteka na ovom poslužitelju.",
"Files are being scanned, please wait." => "Datoteke se skeniraju, molimo pričekajte.",
"Current scanning" => "Trenutno skeniranje"
);
